### 导航

| 工具                        | 文档                                                         |
| --------------------------- | ------------------------------------------------------------ |
| Logger                      | [basic/logger.md](https://github.com/YongJie-Xie/MugwortTools/blob/main/docs/mugwort/basic/logger.md) |
| MultiTask&MultiTaskVariable | [basic/multitask.md](https://github.com/YongJie-Xie/MugwortTools/blob/main/docs/mugwort/basic/multitask.md) |

